Module: Noex

Defined in:
ext/internal/noex/noex.c,
lib/internal/node/pp.rb,
ext/internal/noex/noex.c

Overview

The Noex module contains all the Noex constants from node.h. These constants can be passed to Module#add_method as modifiers to the method being added.

[+PUBLIC+] Method is public. [+UNDEF+] Method is undefined. [+PRIVATE+] Method is private. [+PROTECTED+] Method is protected.

The following are available in Ruby 1.8 and below: [+CFUNC+] Method is a C function.

And these are available in Ruby 1.9 and above: [+NOSUPER+] ??? [+MASK+] ???

Constant Summary collapse

PUBLIC =
INT2NUM(NOEX_PUBLIC)
UNDEF =
INT2NUM(NOEX_UNDEF)
PRIVATE =
INT2NUM(NOEX_PRIVATE)
PROTECTED =
INT2NUM(NOEX_PROTECTED)
CFUNC =
INT2NUM(NOEX_CFUNC)
NOSUPER =
INT2NUM(NOEX_NOSUPER)
MASK =
INT2NUM(NOEX_MASK)

Class Method Summary collapse

Class Method Details

.stringify(noex) ⇒ Object

Return a string representing the given integer as a noex value.



11
12
13
14
15
16
# File 'lib/internal/node/pp.rb', line 11

def stringify(noex)
  Noex.constants.each do |constant|
    return constant.to_s if const_get(constant) == noex
  end
  return noex.to_s
end