Method: Proc#var
- Defined in:
- ext/internal/proc/proc.c
#var ⇒ Node
Returns the Proc’s argument Node.
This method is undefined on YARV.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'ext/internal/proc/proc.c', line 71
static VALUE proc_var(VALUE self)
{
struct BLOCK * b;
if(rb_safe_level() >= 4)
{
/* no access to potentially sensitive data from the sandbox */
rb_raise(rb_eSecurityError, "Insecure: can't get proc var");
}
Data_Get_Struct(self, struct BLOCK, b);
if(b->var == (NODE*)1)
{
/* no parameter || */
return INT2NUM(1);
}
else if(b->var == (NODE*)2)
{
/* also no params, but I'm not sure how this one gets generated */
return INT2NUM(2);
}
else
{
return wrap_node(b->var);
}
}
|